---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2012-08-07;135
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20120814&codiceRedaz=012G0157&dataVigenza=20251104
dataGU: 20120814
codiceRedaz: 012G0157
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 6 luglio 2012, n. 95, recante disposizioni urgenti per la revisione della spesa pubblica con invarianza dei servizi ai cittadini. (12G0157)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 6 luglio 2012, n. 95, recante disposizioni urgenti per la revisione della spesa pubblica con invarianza dei servizi ai cittadini, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base delle norme del decreto-legge 27 giugno 2012, n. 87, non convertite in legge.

3. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base dell'articolo 15, comma 2, del decreto-legge 6 luglio 2012, n. 95.

4. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

